summarylogtreecommitdiffstats
path: root/0001-bas-to-bs.patch
blob: e98c1ed519b502938e368fc9ab2d7596f7c2d132 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
diff --git a/README.md b/README.md
index da928b0..f207637 100644
--- a/README.md
+++ b/README.md
@@ -97,7 +97,7 @@ Apart from the dependencies for the TSTools version, there are some additional d
 
    The following VapourSynth plugins are used by the default scripts set in the default configuration:
    - [`lsmas`](https://github.com/AkarinVS/L-SMASH-Works): For LWLibavSource
-   - [`bas`](https://github.com/vapoursynth/bestaudiosource): For BestAudioSource
+   - [`bs`](https://github.com/vapoursynth/bestsource): For BestSource
    - [`wwxd`](https://github.com/dubhater/vapoursynth-wwxd) and [`scxvid`](https://github.com/dubhater/vapoursynth-scxvid) (depending on settings): For keyframe generation
 
 
diff --git a/src/libresrc/default_config.json b/src/libresrc/default_config.json
index 240998f..b97431a 100644
--- a/src/libresrc/default_config.json
+++ b/src/libresrc/default_config.json
@@ -352,7 +352,7 @@
 				"Aegisub Cache" : true
 			},
 			"VapourSynth" : {
-				"Default Script" : "# This default script will load an audio file using BestAudioSource.\n# It requires the `bas` plugin.\n\nimport vapoursynth as vs\nimport aegisub_vs as a\na.set_paths(locals())\n\na.ensure_plugin(\"bas\", \"BestAudioSource\", \"To use Aegisub's default audio loader, the `bas` plugin for VapourSynth must be installed\")\nvs.core.bas.Source(source=filename).set_output()"
+				"Default Script" : "# This default script will load an audio file using BestSource.\n# It requires the `bs` plugin.\n\nimport vapoursynth as vs\nimport aegisub_vs as a\na.set_paths(locals())\n\na.ensure_plugin(\"bs\", \"BestSource\", \"To use Aegisub's default audio loader, the `bs` plugin for VapourSynth must be installed\")\nvs.core.bs.Source(source=filename).set_output()"
 			}
 		},
 		"Avisynth" : {
@@ -394,7 +394,7 @@
 			},
 			"VapourSynth" : {
 				"Log Level": "Information",
-				"Default Script" : "# This default script will load a video file using LWLibavSource.\n# It requires the `lsmas` plugin.\n# See ?data/automation/vapoursynth/aegisub_vs.py for more information.\n\nimport vapoursynth as vs\nimport time\nimport aegisub_vs as a\na.set_paths(locals())\n\nclip, videoinfo = a.wrap_lwlibavsource(filename)\nclip.set_output()\n__aegi_timecodes = videoinfo[\"timecodes\"]\n__aegi_keyframes = videoinfo[\"keyframes\"]\n\n# Uncomment this line to make Aegisub look for a keyframes file for the video, or ask to detect keyframes on scene changes if no file was found.\n# You can also change the GenKeyframesMode. Valid values are NEVER, ALWAYS, and ASK.\n#__aegi_keyframes = a.get_keyframes(filename, clip, __aegi_keyframes, generate=a.GenKeyframesMode.ASK)\n\n# Check if the file has an audio track. This requires the `bas` plugin.\n__aegi_hasaudio = 1 if a.check_audio(filename) else 0"
+				"Default Script" : "# This default script will load a video file using LWLibavSource.\n# It requires the `lsmas` plugin.\n# See ?data/automation/vapoursynth/aegisub_vs.py for more information.\n\nimport vapoursynth as vs\nimport time\nimport aegisub_vs as a\na.set_paths(locals())\n\nclip, videoinfo = a.wrap_lwlibavsource(filename)\nclip.set_output()\n__aegi_timecodes = videoinfo[\"timecodes\"]\n__aegi_keyframes = videoinfo[\"keyframes\"]\n\n# Uncomment this line to make Aegisub look for a keyframes file for the video, or ask to detect keyframes on scene changes if no file was found.\n# You can also change the GenKeyframesMode. Valid values are NEVER, ALWAYS, and ASK.\n#__aegi_keyframes = a.get_keyframes(filename, clip, __aegi_keyframes, generate=a.GenKeyframesMode.ASK)\n\n# Check if the file has an audio track. This requires the `bs` plugin.\n__aegi_hasaudio = 1 if a.check_audio(filename) else 0"
 			}
 		}
 	},
diff --git a/automation/vapoursynth/aegisub_vs.py b/automation/vapoursynth/aegisub_vs.py
index 65449a4..16bfaf4 100644
--- a/automation/vapoursynth/aegisub_vs.py
+++ b/automation/vapoursynth/aegisub_vs.py
@@ -311,15 +311,15 @@ def get_keyframes(filename: str, clip: vs.VideoNode, fallback: str | List[int],
 def check_audio(filename: str, **kwargs: Any) -> bool:
     """
     Checks whether the given file has an audio track by trying to open it with
     BestAudioSource. Requires the `bas` plugin to return correct results, but
     won't crash if it's not installed.
     Additional keyword arguments are passed on to BestAudioSource.
     """
     progress_set_message("Checking if the file has an audio track")
     progress_set_indeterminate()
     try:
-        ensure_plugin("bas", "BestAudioSource", "")
-        vs.core.bas.Source(source=filename, **kwargs)
+        ensure_plugin("bs", "BestSource", "")
+        vs.core.bs.Source(source=filename, **kwargs)
         return True
     except AttributeError:
         pass
@@ -311,15 +311,15 @@ def get_keyframes(filename: str, clip: vs.VideoNode, fallback: str | List[int],
     """
     Checks whether the given file has an audio track by trying to open it with
-    BestAudioSource. Requires the `bas` plugin to return correct results, but
+    BestSource. Requires the `bs` plugin to return correct results, but
     won't crash if it's not installed.
@@ -311,15 +311,15 @@ def get_keyframes(filename: str, clip: vs.VideoNode, fallback: str | List[int],
     won't crash if it's not installed.
-    Additional keyword arguments are passed on to BestAudioSource.
+    Additional keyword arguments are passed on to BestSource.
     """
     progress_set_message("Checking if the file has an audio track")
-- 
2.43.0